Method: RubyTerraform::ClassMethods#show

Defined in:
lib/ruby_terraform.rb

#show(parameters = {}) ⇒ Object

Invokes the terraform show command which reads and outputs a Terraform state or plan file in a human-readable form. If no path is specified, the current state will be shown.

Examples:

Basic Invocation

RubyTerraform.show

Parameters:

  • parameters (defaults to: {})

    The parameters used to invoke the command

Options Hash (parameters):

  • :path (String)

    The path to a state file or plan to show.

  • :chdir (String)

    The path of a working directory to switch to before executing the given subcommand.

  • :no_color (Boolean) — default: false

    Whether or not the output from the command should be in color.

  • :json (Boolean) — default: false

    If true, outputs the Terraform plan or state in a machine-readable form.



844
845
846
# File 'lib/ruby_terraform.rb', line 844

def show(parameters = {})
  exec(RubyTerraform::Commands::Show, parameters)
end