Method: RubyTerraform::ClassMethods#init
- Defined in:
- lib/ruby_terraform.rb
#init(parameters = {}) ⇒ Object
Invokes the terraform init command which initializes a new or existing Terraform working directory by creating initial files, loading any remote state, downloading modules, etc.
This is the first command that should be run for any new or existing Terraform configuration per machine. This sets up all the local data necessary to run Terraform that is typically not committed to version control.
This command is always safe to run multiple times. Though subsequent runs may give errors, this command will never delete your configuration or state. Even so, if you have important information, please back it up prior to running this command, just in case.
468 469 470 |
# File 'lib/ruby_terraform.rb', line 468 def init(parameters = {}) exec(RubyTerraform::Commands::Init, parameters) end |