Method: RubyTerraform::ClassMethods#providers
- Defined in:
- lib/ruby_terraform.rb
#providers(parameters = {}, invocation_options = {}) ⇒ Object
Invokes the terraform providers command which prints out a tree of modules in the referenced configuration annotated with their provider requirements.
This provides an overview of all of the provider requirements across all referenced modules, as an aid to understanding why particular provider plugins are needed and why particular versions are selected.
699 700 701 702 |
# File 'lib/ruby_terraform.rb', line 699 def providers(parameters = {}, = {}) exec(RubyTerraform::Commands::Providers, parameters, ) end |