Method: RubyTerraform::ClassMethods#show
- Defined in:
- lib/ruby_terraform.rb
#show(parameters = {}) ⇒ Object
Invokes the terraform show command which reads and outputs a Terraform state or plan file in a human-readable form. If no path is specified, the current state will be shown.
844 845 846 |
# File 'lib/ruby_terraform.rb', line 844 def show(parameters = {}) exec(RubyTerraform::Commands::Show, parameters) end |